@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH. group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -99,7 +71,6 @@ import com.openexchange.mailfilter.services.Services;
 import com.openexchange.tools.encoding.Base64;
 import io.micrometer.core.instrument.Metrics;
 import io.micrometer.core.instrument.Timer;
-import net.jodah.failsafe.CircuitBreaker;
 import net.jodah.failsafe.CircuitBreakerOpenException;
 import net.jodah.failsafe.Failsafe;
 import net.jodah.failsafe.FailsafeException;
@@ -138,27 +109,16 @@ public class SieveHandler {
      * The SIEVE AUTHENTICATE.
      */
     private final static String SIEVE_AUTH = "AUTHENTICATE ";
-
     private final static String SIEVE_AUTH_FAILED = "NO \"Authentication Error\"";
-
     private final static String SIEVE_AUTH_LOGIN_USERNAME = "{12}" + CRLF + "VXNlcm5hbWU6";
-
     private final static String SIEVE_AUTH_LOGIN_PASSWORD = "{12}" + CRLF + "UGFzc3dvcmQ6";
-
     private final static String SIEVE_PUT = "PUTSCRIPT ";
-
     private final static String SIEVE_ACTIVE = "SETACTIVE ";
-
     private final static String SIEVE_DEACTIVE = "SETACTIVE \"\"" + CRLF;
-
     private final static String SIEVE_DELETE = "DELETESCRIPT ";
-
     private final static String SIEVE_LIST = "LISTSCRIPTS" + CRLF;
-
     private final static String SIEVE_CAPABILITY = "CAPABILITY" + CRLF;
-
     private final static String SIEVE_GET_SCRIPT = "GETSCRIPT ";
-
     private final static String SIEVE_LOGOUT = "LOGOUT" + CRLF;
 
     private static final int UNDEFINED = -1;
@@ -555,7 +515,7 @@ public class SieveHandler {
             } catch (CircuitBreakerOpenException e) {
                 // Circuit breaker is open
                 circuitBreakerInfo.incrementDenials();
-                throw new IOException("Denied connect attempt to SIEVE server since circuit breaker is open.");
+                throw new IOException("Denied connect attempt to SIEVE server since circuit breaker is open.", e);
             } catch (FailsafeException e) {
                 // Runnable failed with a checked exception
                 Throwable failure = e.getCause();
@@ -1042,7 +1002,7 @@ public class SieveHandler {
             // end if it occurs. We want a list of the script names only
             final String scriptname = temp.substring(temp.indexOf('\"') + 1, temp.lastIndexOf('\"'));
             if (list == null) {
-                list = new ArrayList<String>();
+                list = new ArrayList<>();
             }
             list.add(scriptname);
         }
@@ -1171,7 +1131,7 @@ public class SieveHandler {
 
             boolean active = temp.endsWith(" ACTIVE");
             if (scrips == null) {
-                scrips = new ArrayList<SieveScript>(4);
+                scrips = new ArrayList<>(4);
             }
             scrips.add(new SieveScript(scriptName, active));
         }
@@ -1342,7 +1302,7 @@ public class SieveHandler {
     private boolean authGSSAPI() throws IOException, UnsupportedEncodingException, OXSieveHandlerException {
         final String authname = getRightEncodedString(sieve_auth, "authname");
 
-        final HashMap<String, String> saslProps = new HashMap<String, String>();
+        final HashMap<String, String> saslProps = new HashMap<>();
 
         // Mutual authentication
         saslProps.put("javax.security.sasl.server.authentication", "true");
@@ -1546,7 +1506,7 @@ public class SieveHandler {
      * Parse the https://tools.ietf.org/html/rfc5804#section-1.3 Response code of a SIEVE
      * response line.
      *
-     * @param multiline TODO
+     * @param multiline The multiline response
      * @param response line
      * @return null, if no response code in line, the @{SIEVEResponse.Code} otherwise.
      */
@@ -1712,7 +1672,7 @@ public class SieveHandler {
         WelcomeKeyword keyword;
         try {
             keyword = WelcomeKeyword.valueOf(token);
-        } catch (IllegalArgumentException e) {
+        } catch (@SuppressWarnings("unused") IllegalArgumentException e) {
             log.debug("Unknown keyword '{}'", token);
             capa.addExtendedProperty(token, Strings.unquote(value));
             return;
@@ -1979,7 +1939,7 @@ public class SieveHandler {
                 try {
                     hostAddress = InetAddress.getByName(sieveHandler.sieve_host).getHostAddress();
                     host = hostAddress + ':' + sieveHandler.sieve_host_port;
-                } catch (UnknownHostException e) {
+                } catch (@SuppressWarnings("unused") UnknownHostException e) {
                     // ignore;
                 }
             }
@@ -1998,6 +1958,13 @@ public class SieveHandler {
             return !measureRead();
         }
 
+        /**
+         * Updates the request timer
+         *
+         * @param duration The duration
+         * @param timeUnit The time unit
+         * @param status The status
+         */
         public void updateRequestTimer(long duration, TimeUnit timeUnit, String status) {
             Timer.builder("appsuite.mailfilter.commands")
             .description("Mail filter commands per host")
