@@ -1,49 +1,21 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH. group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
@@ -58,6 +30,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
+import java.util.Hashtable;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -94,6 +67,7 @@ import com.openexchange.jsieve.commands.Rule;
 import com.openexchange.jsieve.commands.RuleComment;
 import com.openexchange.jsieve.commands.TestCommand;
 import com.openexchange.jsieve.commands.TestCommand.Commands;
+import com.openexchange.jsieve.commands.test.IActionCommand;
 import com.openexchange.jsieve.commands.test.ITestCommand;
 import com.openexchange.jsieve.export.Capabilities;
 import com.openexchange.jsieve.export.RuleConverter;
@@ -245,31 +219,24 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 if (delayMillis <= 0) {
                     throw new IllegalArgumentException("windowMillis must be greater than 0 (zero).");
                 }
-                circuitBreaker = new CircuitBreaker()
-                    .withFailureThreshold(failureThreshold, failureExecutions)
-                    .withSuccessThreshold(successThreshold, successExecutions)
-                    .withDelay(delayMillis, TimeUnit.MILLISECONDS)
-                    .onOpen(() -> {
-                        CircuitBreakerInfo circuitBreakerInfo = optionalCircuitBreaker.get();
-                        if (circuitBreakerInfo != null) {
-                            circuitBreakerInfo.incrementOpens();
-                        }
-                    })
-                    .onHalfOpen(new CheckedRunnable() {
+                circuitBreaker = new CircuitBreaker().withFailureThreshold(failureThreshold, failureExecutions).withSuccessThreshold(successThreshold, successExecutions).withDelay(delayMillis, TimeUnit.MILLISECONDS).onOpen(() -> {
+                    CircuitBreakerInfo circuitBreakerInfo = optionalCircuitBreaker.get();
+                    if (circuitBreakerInfo != null) {
+                        circuitBreakerInfo.incrementOpens();
+                    }
+                }).onHalfOpen(new CheckedRunnable() {
 
-                        @Override
-                        public void run() throws Exception {
-                            LOGGER.info("Mail filter circuit breaker half-opened");
-                        }
-                    })
-                    .onClose(new CheckedRunnable() {
-
-                        @Override
-                        public void run() throws Exception {
-                            LOGGER.info("Mail filter circuit breaker closed");
-                        }
-                    });
+                    @Override
+                    public void run() throws Exception {
+                        LOGGER.info("Mail filter circuit breaker half-opened");
+                    }
+                }).onClose(new CheckedRunnable() {
 
+                    @Override
+                    public void run() throws Exception {
+                        LOGGER.info("Mail filter circuit breaker closed");
+                    }
+                });
 
             } catch (RuntimeException e) {
                 LOGGER.warn("Invalid configuration for mail filter circuit breaker", e);
@@ -283,7 +250,6 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
 
     }
 
-
     /**
      * Creates a new {@link CircuitBreakerInfo} instance for given {@link CircuitBreaker} and initializes
      * its monitoring metrics.
@@ -471,7 +437,7 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 // Check redirect limit
                 checkRedirects(rule, credentials);
 
-                changeIncomingVacationRule(credentials.getUserid(), credentials.getContextid(), rightRule.rule);
+                changeIncomingVacationRule(credentials.getUserid(), credentials.getContextid(), rule);
                 if (rightRule.position == rule.getPosition()) {
                     clientRulesAndReq.getRules().set(rightRule.position, rule);
                 } else {
@@ -785,8 +751,8 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
                 if (rightRule == null) {
                     return null;
                 }
-
-                return rightRule.rule;
+                return applyOptionalCopyRequired(rightRule.rule);
+                //return rightRule.rule;
             } catch (UnsupportedEncodingException e) {
                 throw MailFilterExceptionCode.UNSUPPORTED_ENCODING.create(e);
             } catch (OXSieveHandlerException e) {
@@ -891,6 +857,32 @@ public final class MailFilterServiceImpl implements MailFilterService, Reloadabl
 
     // ----------------------------------------------------------------------------------------------------------------------- //
 
+    /**
+     * Applies the optional <code>copy</code> required for the {@link ActionCommand.Commands#FILEINTO} and {@link ActionCommand.Commands#REDIRECT}
+     * action commands.
+     * 
+     * @param rule The rule
+     * @return The rule
+     */
+    private Rule applyOptionalCopyRequired(Rule rule) {
+        IfCommand ifCommand = rule.getIfCommand();
+        if (ifCommand == null) {
+            return rule;
+        }
+        for (ActionCommand actionCommand : ifCommand.getActionCommands()) {
+            IActionCommand command = actionCommand.getCommand();
+            if (false == command.equals(ActionCommand.Commands.FILEINTO) && false == command.equals(ActionCommand.Commands.REDIRECT)) {
+                continue;
+            }
+            Hashtable<String, List<String>> tagArguments = actionCommand.getTagArguments();
+            if (tagArguments.containsKey(":copy")) {
+                ifCommand.addOptionalRequired("copy");
+                break;
+            }
+        }
+        return rule;
+    }
+
     /**
      * Get the script name for the specified user in the specified context
      *
